@@ -14,7 +14,6 @@ import fnmatch
 import uuid
 import re
 import getpass
-import tarfile
 import time
 from lxml import etree
 from ovf import ovfenvelope
@@ -489,36 +488,57 @@ class ImageUploader(object):
                         vrm
                     )
                 else:
-                    logging.error(_("Unable to connect to REST API."))
+                    logging.error(
+                        _(
+                            "Unable to connect to REST API at {url}"
+                        ).format(
+                            url=url,
+                        )
+                    )
                     return False
-            except RequestError, re_e:
+            except RequestError as re_e:
                 logging.error(
-                    _("Unable to connect to REST API.  Reason: %s"),
-                    re_e.reason
+                    _(
+                        "Unable to connect to REST API at {url}\n"
+                        "Reason: {reason}"
+                    ).format(
+                        url=url,
+                        reason=re_e.reason,
+                    ),
+
                 )
                 return False
             except ConnectionError:
                 logging.error(
                     _(
-                        "Problem connecting to the REST API.  Is the "
-                        "service available and does the CA certificate "
+                        "Problem connecting to the REST API at {url}\n"
+                        "Is the service available and does the CA certificate "
                         "exist?"
+                    ).format(
+                        url=url,
                     )
                 )
                 return False
             except NoCertificatesError:
                 logging.error(
                     _(
-                        "Problem connecting to the REST API.  The CA is "
-                        "invalid.  To override use the \'insecure\' "
+                        "Problem connecting to the REST API at {url}\n"
+                        "The CA is invalid. To override use the \'insecure\' "
                         "option."
+                    ).format(
+                        url=url,
                     )
                 )
                 return False
-            except Exception, e:
+            except Exception as e:
                 logging.error(
-                    _("Unable to connect to REST API.  Message: %s"),
-                    e
+                    _(
+                        "Unable to connect to REST API at {url}\n"
+                        "Message: {e}"
+                    ).format(
+                        url=url,
+                        e=e,
+                    ),
                 )
                 return False
         return True
@@ -695,21 +715,36 @@ class ImageUploader(object):
         Checks to see if there is enough room to decompress the tgz into
         dest_dir
         """
-        tar = tarfile.open(ovf_file, "r:gz")
         size_in_bytes = 0
-        try:
-            for tarinfo in tar:
-                if tarinfo.isreg():
-                    size_in_bytes += tarinfo.size
-        except:
+        exttar = subprocess.Popen(
+            ['tar', '-tvzf', ovf_file],
+            shell=False,
+            stdout=subprocess.PIPE,
+            stderr=subprocess.PIPE,
+        )
+        outerr = exttar.communicate()
+        rc = exttar.returncode
+        if rc == 2:
+            raise Exception(
+                _("not a gzip file")
+            )
+        if outerr[1] != '':
             logging.error(
                 _(
                     "Unable to calculate the decompressed size of %s."
                 ) % ovf_file
             )
-            return (False, -1)
-        finally:
-            tar.close()
+            return False, -1
+        for line in outerr[0].splitlines():
+            try:
+                size_in_bytes += int(line.split()[2])
+            except (ValueError, IndexError):
+                logging.error(
+                    _(
+                        "Unable to calculate the decompressed size of %s."
+                    ) % ovf_file
+                )
+                return False, -1
 
         dest_dir_stat = os.statvfs(dest_dir)
         dest_dir_size = (dest_dir_stat.f_bavail * dest_dir_stat.f_frsize)
@@ -729,9 +764,9 @@ class ImageUploader(object):
         )
 
         if dest_dir_size > size_in_bytes:
-            return (True, size_in_bytes)
+            return True, size_in_bytes
         else:
-            return (False, size_in_bytes)
+            return False, size_in_bytes
 
     def space_test_nfs(self, remote_dir, desired_size, uid, gid):
         """
@@ -807,10 +842,10 @@ class ImageUploader(object):
         logging.debug("euid(%s) egid(%s)" % (os.geteuid(), os.getegid()))
         umask_save = os.umask(0137)  # Set to 660
         try:
-            src = open(src_file_name, 'r')
+            src = open(src_file_name, 'rb')
             os.setegid(gid)
             os.seteuid(uid)
-            dest = open(dest_file_name, 'w')
+            dest = open(dest_file_name, 'wb')
             self.copyfileobj_sparse(src, dest)
         except Exception, e:
             retVal = False
